VeraCrypt
aboutsummaryrefslogtreecommitdiff
path: root/src/Build
diff options
context:
space:
mode:
authorMounir IDRASSI <mounir.idrassi@idrix.fr>2017-06-13 16:40:05 +0200
committerMounir IDRASSI <mounir.idrassi@idrix.fr>2017-06-13 18:21:13 +0200
commit5d0321291f4df297b0d9f9837099a36cdf1c83b6 (patch)
treed90894454931f927bcc13382d3d47db9856c1d4b /src/Build
parenteb4f5ac4e7fedae6061a9615d41dd6c2c8779c92 (diff)
downloadVeraCrypt-5d0321291f4df297b0d9f9837099a36cdf1c83b6.tar.gz
VeraCrypt-5d0321291f4df297b0d9f9837099a36cdf1c83b6.zip
Linux/MacOSX: Modify Makefile to separate between build and packaging. Add install target for local installation.
Diffstat (limited to 'src/Build')
-rwxr-xr-xsrc/Build/build_veracrypt_linux.sh8
-rwxr-xr-xsrc/Build/build_veracrypt_macosx.sh8
2 files changed, 8 insertions, 8 deletions
diff --git a/src/Build/build_veracrypt_linux.sh b/src/Build/build_veracrypt_linux.sh
index 8e16ebfe..deed925b 100755
--- a/src/Build/build_veracrypt_linux.sh
+++ b/src/Build/build_veracrypt_linux.sh
@@ -31,17 +31,17 @@ echo "Building GUI version of VeraCrypt"
# this will be the temporary wxWidgets directory
export WX_BUILD_DIR=$PARENTDIR/wxBuildGui
-make WXSTATIC=1 wxbuild && make WXSTATIC=1 clean && make WXSTATIC=1
+make WXSTATIC=1 wxbuild && make WXSTATIC=1 clean && make WXSTATIC=1 && make WXSTATIC=1 package
# Uncomment below and comment line above to reuse existing wxWidgets build
# make WXSTATIC=1 clean && make WXSTATIC=1
echo "Building console version of VeraCrypt"
# this will be the temporary wxWidgets directory
export WX_BUILD_DIR=$PARENTDIR/wxBuildConsole
-make WXSTATIC=1 NOGUI=1 wxbuild && make WXSTATIC=1 NOGUI=1 clean && make WXSTATIC=1 NOGUI=1
+make WXSTATIC=1 NOGUI=1 wxbuild && make WXSTATIC=1 NOGUI=1 clean && make WXSTATIC=1 NOGUI=1 && make WXSTATIC=1 NOGUI=1 package
# Uncomment below and comment line above to reuse existing wxWidgets build
# make WXSTATIC=1 NOGUI=1 clean && make WXSTATIC=1 NOGUI=1
@@ -31,17 +31,17 @@ echo "Building GUI version of VeraCrypt"
# Uncomment below and comment line above to reuse existing wxWidgets build
-# make WXSTATIC=1 clean && make WXSTATIC=1
+# make WXSTATIC=1 clean && make WXSTATIC=1 && make WXSTATIC=1 package
echo "Building console version of VeraCrypt"
# this will be the temporary wxWidgets directory
@@ -31,17 +31,17 @@ echo "Building GUI version of VeraCrypt"
# Uncomment below and comment line above to reuse existing wxWidgets build
-# make WXSTATIC=1 NOGUI=1 clean && make WXSTATIC=1 NOGUI=1
+# make WXSTATIC=1 NOGUI=1 clean && make WXSTATIC=1 NOGUI=1 && make WXSTATIC=1 NOGUI=1 package
diff --git a/src/Build/build_veracrypt_macosx.sh b/src/Build/build_veracrypt_macosx.sh
index f8146422..ba325d4b 100755
--- a/src/Build/build_veracrypt_macosx.sh
+++ b/src/Build/build_veracrypt_macosx.sh
@@ -12,8 +12,8 @@ SOURCEPATH=$(cd "$(dirname "$SCRIPTPATH/../.")"; pwd)
# directory where the VeraCrypt project has been checked out
PARENTDIR=$(cd "$(dirname "$SCRIPTPATH/../../../.")"; pwd)
-# the sources of wxWidgets 3.0.2 must be extracted to the parent directory
-export WX_ROOT=$PARENTDIR/wxWidgets-3.0.2
+# the sources of wxWidgets 3.0.3 must be extracted to the parent directory
+export WX_ROOT=$PARENTDIR/wxWidgets-3.0.3
echo "Using wxWidgets sources in $WX_ROOT"
# this will be the temporary wxWidgets directory
@@ -27,7 +27,7 @@ echo "Using MacOSX SDK $VC_OSX_TARGET"
cd $SOURCEPATH
echo "Building VeraCrypt"
-make WXSTATIC=1 wxbuild && make WXSTATIC=1 clean && make WXSTATIC=1
+make WXSTATIC=1 wxbuild && make WXSTATIC=1 clean && make WXSTATIC=1 && make WXSTATIC=1 package
# Uncomment below and comment line above to reuse existing wxWidgets build
# make WXSTATIC=1 clean && make WXSTATIC=1
@@ -27,7 +27,7 @@ echo "Using MacOSX SDK $VC_OSX_TARGET"
# Uncomment below and comment line above to reuse existing wxWidgets build
-# make WXSTATIC=1 clean && make WXSTATIC=1
+# make WXSTATIC=1 clean && make WXSTATIC=1 && make WXSTATIC=1 package